package com.mx.cneeds.server.datashow.web.device;

import com.mx.cneeds.common.constant.ResultCode;
import com.mx.cneeds.common.converter.RequestParamterConverter;
import com.mx.cneeds.common.dto.*;
import com.mx.cneeds.common.result.R;
import com.mx.cneeds.common.vo.DeviceChannelVo;
import com.mx.cneeds.common.vo.DevicesVo;
import com.mx.cneeds.common.vo.SeriesVo;
import com.mx.cneeds.server.datashow.client.DeviceClient;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName DeviceController
 * @Author zzrdark
 * @Date 2020-03-05 14:42
 * @Description TODO
 **/

@RestController
@Slf4j
@RequestMapping("/device")
public class DeviceController {

    @Autowired
    private DeviceClient deviceClient;

    @GetMapping("/device/getChannel_nums")
    public R getChannel_nums(String imei){

        DeviceChannelVo channelVo = new DeviceChannelVo();
        DeviceInfoDto deviceInfoDto = null;
        try {
            deviceInfoDto = deviceClient.queryDeviceByImei(imei);
            if (deviceInfoDto == null){
                log.debug("ResultCode:"+ResultCode.NOTFOUND_IMEI);
                return R.error(ResultCode.NOTFOUND_IMEI,"没有该imei的设备");
            }
        }catch (Exception e) {
            return R.error(ResultCode.NOTFOUND_IMEI,"没有该imei的设备");
        }

        if (deviceInfoDto.getChannelNums() == null || deviceInfoDto.getChannelRules() == null) {
            return R.error(ResultCode.NOTSET_CHANNEL,"该设备没有设置渠道商号");
        }

        BeanUtils.copyProperties(deviceInfoDto,channelVo);
        return new R().put("data",channelVo);
    }

    @PostMapping("/device/saveChannel")
    public R saveChannel_nums(DeviceChannelVo channelVo){
        DevicesDto devicesDto = new DevicesDto();
        BeanUtils.copyProperties(channelVo,devicesDto);
        deviceClient.updateDeviceChannelBatch(devicesDto);

        return new R().put("data",channelVo);
    }




    @PostMapping("/series/list")
    public R seriesList(@RequestParam(required = false) Integer page,
                      @RequestParam(required = false) Integer pageSize,
                      @RequestParam(required = false) String sort){

        String orderField = null;
        String order = null;

        if (page==null || page==0){
            page = new Integer(1);
        }
        if (pageSize==null || pageSize==0){
            pageSize = new Integer(10);
        }

        if (StringUtils.isNotEmpty(sort) && StringUtils.isNotBlank(sort.trim())){
            if (sort.contains("+")){
                order = new String("asc");
            }
            if (sort.contains("-")){
                order = new String("desc");
            }
            orderField = sort.substring(1);
            orderField = RequestParamterConverter.toLine(orderField);
        }


        PageDto pageDto = deviceClient.seriesList(page,pageSize,orderField,order);

        return new R().put("data",pageDto);
    }

    @PostMapping("/series/listAll")
    public R selectSeries(){
        List<SeriesDto> seriesDtos = deviceClient.seriesListAll();

        return new R().put("data",seriesDtos);
    }

    @PostMapping("/series/add")
    public R addSeries(SeriesVo seriesVo){
        SeriesDto querySeries = deviceClient.querySeries(seriesVo.getSeriesNum());
        if (querySeries != null){
            return R.error(ResultCode.DATA_REPEATITION,"系列号重复");
        }

        SeriesDto seriesDto = new SeriesDto();

        BeanUtils.copyProperties(seriesVo,seriesDto);
        deviceClient.addSeries(seriesDto);
        return R.ok();

    }

    @PostMapping("/series/edit")
    public R editSeries(SeriesVo seriesVo){

        SeriesDto seriesDto = new SeriesDto();

        BeanUtils.copyProperties(seriesVo,seriesDto);
        deviceClient.updateSeries(seriesDto);
        return R.ok();

    }

    @PostMapping("/series/delete")
    public R deleteSeries(@RequestParam(value = "ids",required = false) List<Long> ids){
        deviceClient.deleteSeries(ids);
        return R.ok();

    }


    @PostMapping("/device/list")
    public R deviceList(@RequestParam(required = false) Integer page,
                        @RequestParam(required = false) Integer pageSize,
                        @RequestParam(required = false) String sort){

        String orderField = null;
        String order = null;

        if (page==null || page==0){
            page = new Integer(1);
        }
        if (pageSize==null || pageSize==0){
            pageSize = new Integer(10);
        }

        if (StringUtils.isNotEmpty(sort) && StringUtils.isNotBlank(sort.trim())){
            if (sort.contains("+")){
                order = new String("asc");
            }
            if (sort.contains("-")){
                order = new String("desc");
            }
            orderField = sort.substring(1);
            orderField = RequestParamterConverter.toLine(orderField);
        }
        PageDto pageDto = deviceClient.deviceList(page,pageSize,orderField,order);

        return new R().put("data",pageDto);
    }

    @PostMapping("/device/importDevice")
    public R importDevice(DevicesVo devicesVo){
        DevicesDto devicesDto = new DevicesDto();

        BeanUtils.copyProperties(devicesVo,devicesDto);
        deviceClient.importDevice(devicesDto);
        return R.ok();

    }

    @PostMapping("/device/updateDeviceSeriesBatch")
    public R updateDeviceSeriesBatch(DevicesVo devicesVo){
        DevicesDto devicesDto = new DevicesDto();

        BeanUtils.copyProperties(devicesVo,devicesDto);
        deviceClient.updateDeviceSeriesBatch(devicesDto);
        return R.ok();

    }

    @PostMapping("/device/delete")
    public R deleteDevice(@RequestParam(value = "ids",required = false) List<Long> ids){
        deviceClient.deleteDevice(ids);
        return R.ok();

    }

    @PostMapping("/device/queryDeviceByImei")
    public R queryDeviceByImei(@RequestBody DeviceInfoDto dto){
        log.debug("queryDeviceByImei: imei:" + dto.getImei());
        DeviceInfoDto deviceInfoDto = deviceClient.queryDeviceByImei(dto.getImei());
        if (deviceInfoDto == null){
            R.error(ResultCode.NOTFOUND_IMEI,"没有该imei的设备");
        }
        return R.ok().put("data",deviceInfoDto);
    }


}
